@@ -1,8 +1,8 @@
 from abc import ABCMeta, abstractmethod
 from typing import Dict, Union
 
-from nidhoggr.core.response import StatusResponse, ErrorResponse
-from nidhoggr.core.texture import TextureType, TextureItem
+from nidhoggr.core.response import StatusResponse, TextureStatusResponse, ErrorResponse
+from nidhoggr.core.texture import TextureType, TextureItem, TextureUploadRequest, TextureRequest
 from nidhoggr.core.user import User
 
 
@@ -10,12 +10,19 @@ class BaseTextureRepo(metaclass=ABCMeta):
     variant: str
 
     @abstractmethod
-    def get(self, *, uuid: str) -> Union[ErrorResponse, Dict[TextureType, TextureItem]]:
+    def get(self, *, request: TextureRequest) -> Union[ErrorResponse, Dict[TextureType, TextureItem]]:
+        pass
+
+    @abstractmethod
+    def upload(self, *, request: TextureUploadRequest) -> Union[ErrorResponse, TextureStatusResponse]:
+        pass
+
+    @abstractmethod
+    def clear(self, *, request: TextureRequest) -> Union[ErrorResponse, TextureStatusResponse]:
         pass
 
 
 class BaseUserRepo(metaclass=ABCMeta):
-
     EMPTY_USER = User(
         uuid="00000000000000000000000000000000",
         login="empty",
