@@ -28,6 +28,16 @@ class TextureRequest(BaseModel):
         allow_mutation = False
 
 
+class TextureUploadRequest(BaseModel):
+    uuid: str
+    data: str
+    kind: TextureType
+    metadata: TextureMeta
+
+    class Config:
+        allow_mutation = False
+
+
 class TextureResponse(BaseModel):
     textures: Dict[TextureType, TextureItem]
 
